.. _api_schema:

flameiq.schema — Data Models
==============================

.. automodule:: flameiq.schema.v1.models
   :members:
   :undoc-members:
   :show-inheritance:
   :special-members: __post_init__
